Image class

Properties

block → Pointer<Uint8>
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → int
no setter
linesize → int
no setter
mode → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
no setter

Methods

blend(Image other, double alpha) → Image
copy() → Image
flipLeftRight() → Image
flipTopBottom() → Image
free() → void
gaussianBlur(double radius, int passes) → Image
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resample(int width, int height, Transform mode) → Image
rotate180() → Image
rotate270() → Image
rotate90() → Image
toBlurhash(int xComponents, int yComponents) → String
toJpeg(int quality) → Future<Uint8List>
toString() → String
A string representation of this object.
inherited
transpose() → Image
transverse() → Image

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromRGBA(int width, int height, List<int> data) → Image
loadEncoded(Uint8List bytes) → Future<Image>